summaryrefslogtreecommitdiff
path: root/src/include/taler_testing_lib.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-01-15 15:44:24 +0100
committerChristian Grothoff <christian@grothoff.org>2020-01-15 15:44:24 +0100
commit19d9369ff6df2e4bfd896cce5fcb2ae679402bc0 (patch)
tree50244c37699441e957c11129dd19f97af18521a4 /src/include/taler_testing_lib.h
parent9ded20518c5a11a43b2b05d04d0922b1a1d36e2b (diff)
downloadexchange-19d9369ff6df2e4bfd896cce5fcb2ae679402bc0.tar.gz
exchange-19d9369ff6df2e4bfd896cce5fcb2ae679402bc0.tar.bz2
exchange-19d9369ff6df2e4bfd896cce5fcb2ae679402bc0.zip
add another interpreter command to check incoming wire transfers
Diffstat (limited to 'src/include/taler_testing_lib.h')
-rw-r--r--src/include/taler_testing_lib.h23
1 files changed, 21 insertions, 2 deletions
diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index 9f638bd66..554106cd8 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -1352,8 +1352,8 @@ TALER_TESTING_cmd_track_transfer (const char *label,
const char *expected_wire_fee);
/**
* Make a "bank check" CMD. It checks whether a
* particular wire transfer has been made or not.
*
* @param label the command label.
* @param exchange_base_url base url of the exchange involved in
@@ -1372,6 +1372,25 @@ TALER_TESTING_cmd_check_bank_transfer (const char *label,
/**
+ * Make a "bank check" CMD. It checks whether a particular wire transfer to
+ * the exchange (credit) has been made or not.
+ *
+ * @param label the command label.
+ * @param amount the amount expected to be transferred.
+ * @param debit_payto the account that gave money.
+ * @param credit_payto the account that received money.
+ * @param reserve_pub_ref command that provides the reserve public key to expect
+ * @return the command
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_check_bank_admin_transfer (const char *label,
+ const char *amount,
+ const char *debit_payto,
+ const char *credit_payto,
+ const char *reserve_pub_ref);
+
+
+/**
* Define a "bank check" CMD that takes the input
* data from another CMD that offers it.
*
@@ -1352,8 +1352,8 @@ TALER_TESTING_cmd_track_transfer (const char *label,
const char *expected_wire_fee);
/**
- * Make a "bank check" CMD. It checks whether a
- * particular wire transfer has been made or not.
+ * Make a "bank check" CMD. It checks whether a particular wire transfer from
+ * the exchange (debit) has been made or not.
*
* @param label the command label.